@@ -92,11 +92,24 @@
                             by = c(id, strata))) > 0) {
     stop("There are `id=`/`strata=` combinations in `data=` not found in `id_df=`.", call. = FALSE)
   }
+
+  # check for missing soc
+  if (!is.null(soc) && any(is.na(data[soc]))) {
+    stop("At least one `soc` is missing.", call. = FALSE)
+  }
+
+  # check for missing ae
+  if (!is.null(ae) && any(is.na(data[ae]))) {
+    stop("At least one `ae` is missing.", call. = FALSE)
+  }
+
+  # check for an ae listed under more than one soc
   if (!is.null(soc) &&
       nrow(dplyr::distinct(data[c(ae, soc)])) != nrow(dplyr::distinct(data[ae]))) {
     stop("The `ae` levels must be unique across all `soc` levels.", call. = FALSE)
   }
 
+
   # some default factor levels -------------------------------------------------
   initial_missing <- missing_text
   initial_dummy   <- "NOT OBSERVED"
@@ -140,7 +153,7 @@
     tidyr::drop_na(!!!rlang::syms(intersect(c("soc", "ae"), names(data))))
 
   # replace unobserved AEs with an explicit level ------------------------------
-  data_full$by <- forcats::fct_explicit_na(data_full$by, initial_dummy)
+  data_full$by <- .fct_explicit_na(data_full$by, initial_dummy)
 
   # re-level to put unobserved and missing in front
   if (any(c(initial_dummy, initial_missing) %in% levels(data_full$by))) {
@@ -236,7 +249,7 @@
 
   # adding missing level, as needed
   if (any(is.na(data$by))) {
-    data$by <- forcats::fct_explicit_na(data$by, na_level = initial_missing)
+    data$by <- .fct_explicit_na(data$by, na_level = initial_missing)
   }
 
   data
