@@ -247,3 +247,82 @@
   tbl
 }
 
+# check_factor is not an exported function in forcats, copying here
+# for internal use
+.check_factor <- function(x) {
+  if (is.character(x)) {
+    factor(x)
+  } else if (is.factor(x)) {
+    x
+  } else {
+    cli::cli_abort(
+      "Input must be a factor or character vector."
+    )
+  }
+}
+
+# keeping deprecated forcats function in order
+# to not change default behavior with new functions
+.fct_explicit_na <- function(f, na_level = "(Missing)") {
+
+  f <- .check_factor(f)
+
+  is_missing <- is.na(f)
+  is_missing_level <- is.na(levels(f))
+
+  if (any(is_missing)) {
+    f <- forcats::fct_expand(f, na_level)
+    f[is_missing] <- na_level
+
+    f
+  } else if (any(is_missing_level)) {
+    levs <- levels(f)
+    levs[is.na(levs)] <- na_level
+
+    forcats::lvls_revalue(f, levs)
+  } else {
+    f
+  }
+}
+
+# internal version of purrr::when() due to deprecation
+.when <- function(., ...) {
+
+  dots   <- list(...)
+  names  <- names(dots)
+  named  <- if (is.null(names)) rep(FALSE, length(dots)) else names != ""
+
+  if (sum(!named) == 0)
+    cli::cli_abort("At least one matching condition is needed.")
+
+  is_formula <-
+    vapply(dots,
+           function(dot) identical(class(dot), "formula"),
+           logical(1L))
+
+  env <- new.env(parent = parent.frame())
+  env[["."]] <- .
+
+  if (sum(named) > 0)
+    for (i in which(named))
+      env[[names[i]]] <- dots[[i]]
+
+  result <- NULL
+  for (i in which(!named)) {
+    if (is_formula[i]) {
+      action <- length(dots[[i]])
+      if (action == 2 || rlang::is_true(eval(dots[[i]][[2]], env, env))) {
+        result <- eval(dots[[i]][[action]], env, env)
+        break
+      }
+    } else {
+      result <- dots[[i]]
+    }
+  }
+
+  result
+}
+
+
+
+
